@@ -35,9 +35,11 @@ use Data::Dumper;
 use Carp;
 use File::Spec::Functions;
 
+use Xacobeo;
 use Xacobeo::DomModel;
 use Xacobeo::Document;
 use Xacobeo::Utils qw(:xml :dom);
+use Xacobeo::I18n;
 use Xacobeo::Timer;
 use Xacobeo::XS qw(
 	xacobeo_populate_gtk_text_buffer
@@ -75,6 +77,10 @@ Parameters:
 
 The application's root folder.
 
+=item * $domain
+
+The i18n (gettext) domain to use for the translations.
+
 =back	
 
 =cut
@@ -82,15 +88,15 @@ The application's root folder.
 sub new {
 	# Arguments
 	my $class = shift;
-	croak 'Usage: new($app_folder)' unless @_;
-	my ($app_folder) = @_;
+	croak 'Usage: new($app_folder, $domain)' unless @_ == 2;
+	my ($app_folder, $domain) = @_;
 	
 	# Create an instance
 	my $self = bless {}, ref($class) || $class;
 	
 	# Create the GUI
 	$self->app_folder($app_folder);
-	$self->construct_gui();
+	$self->construct_gui($domain);
 	
 	# Return the new instances
 	return $self;
@@ -103,12 +109,17 @@ sub new {
 sub construct_gui {
 	# Arguments
 	my $self = shift;
+	my ($domain) = @_;
 
 	my $folder = $self->app_folder();
 	
 	# Load the GUI definition from the glade files
 	Gtk2::Glade->set_custom_handler(\&glade_custom_handler, $self);
-	my $glade = Gtk2::GladeXML->new(catfile($folder, 'share', 'xacobeo', 'xacobeo.glade'));
+	my $glade = Gtk2::GladeXML->new(
+		catfile($folder, 'share', 'xacobeo', 'xacobeo.glade'),
+		undef,
+		$domain,
+	);
 	$self->glade($glade);
 	
 	my $window = $self->glade->get_widget('window');
@@ -120,11 +131,12 @@ sub construct_gui {
 	$self->glade->get_widget('about')->set_logo($logo);
 
 	# Parse the Pango markup for the default value of the xpath entry widget
-	($self->{xpath_empty_attributes}, $self->{xpath_empty_text}) = Gtk2::Pango->parse_markup(
-		"<span color='grey' size='smaller'>XPath Expression...</span>"
+	($self->{xpath_empty_attributes}, $self->{xpath_empty_text}) = pango_span(
+		__("XPath Expression..."),
+		color => 'grey',
+		size  => 'smaller',
 	);
 
-
 	# Connect the signals to the callbacks
 	$glade->signal_autoconnect_from_package($self);
 	
@@ -141,6 +153,9 @@ sub construct_gui {
 	
 	# Create the list model for the Namespace view
 	$self->construct_namespaces_view();
+	
+	# Add the version to the about dialog
+	$self->glade->get_widget('about')->set_version($Xacobeo::VERSION);
 }
 
 
@@ -320,7 +335,7 @@ sub load_file {
 	my $timer = Xacobeo::Timer->start();
 	
 	# Parse the content
-	my $t_load = Xacobeo::Timer->start('Load document');
+	my $t_load = Xacobeo::Timer->start(__('Load document'));
 	my $document = Xacobeo::Document->new($file);
 	$self->document($document);
 	undef $t_load;
@@ -332,12 +347,12 @@ sub load_file {
 	my $namespaces = $document->namespaces;
 
 	# Update the text widget
-	my $t_syntax = Xacobeo::Timer->start('Syntax Highlight');
+	my $t_syntax = Xacobeo::Timer->start(__('Syntax Highlight'));
 	$self->display_xml_node('xml-document', $xml);
 	undef $t_syntax;
 
 	# Populate the DOM view tree
-	my $t_dom = Xacobeo::Timer->start('DOM Tree');
+	my $t_dom = Xacobeo::Timer->start(__('DOM Tree'));
 	$self->populate_treeview($xml);
 	undef $t_dom;
 	$timer->stop();
@@ -350,9 +365,12 @@ sub load_file {
 	}
 	@{ $self->namespaces_view->{data} } = @namespaces;
 
-	$self->display_statusbar_message(
-		sprintf "Document loaded in %.3f s", $timer->elapsed
+	my $format = __n(
+		"Document loaded in %.3f second", 
+		"Document loaded in %.3f seconds", 
+		int($timer->elapsed),
 	);
+	$self->display_statusbar_message(sprintf $format, $timer->elapsed);
 	
 	$glade->get_widget('xpath-entry')->set_sensitive(TRUE);
 }
@@ -588,9 +606,10 @@ sub callback_xpath_entry_changed {
 		}
 		else {
 			# Mark the XPath expression as wrong
-			my $escaped = escape_xml_text($xpath);
-			my $markup = "<span underline='error' underline_color='red'>$escaped</span>";
-			($pango_attributes) = Gtk2::Pango->parse_markup($markup);
+			#my $escaped = escape_xml_text($xpath);
+			#my $markup = "<span underline='error' underline_color='red'>$escaped</span>";
+			#($pango_attributes) = Gtk2::Pango->parse_markup($markup);
+			($pango_attributes) = pango_span($xpath, underline => 'error', underline_color => 'red');
 		}
 	}
 	$self->glade->get_widget('xpath-evaluate')->set_sensitive($xpath_valid);
@@ -672,7 +691,8 @@ sub callback_file_selected {
 #
 sub callback_about_show {
 	my $self = shift;
-	$self->glade->get_widget('about')->show_all();
+	my $about = $self->glade->get_widget('about');
+	$about->show_all();
 }
 
 
@@ -819,6 +839,26 @@ sub create_xpath_results_view {
 }
 
 
+#
+# Returns the Pango attribute list and the text from a Pango markup span that
+# would have the given attributes.
+#
+# This function creates a span element with the given attributes that wraps the
+# given text. The text has it's content escaped.
+#
+sub pango_span {
+	my ($text, %attributes) = @_;
+	
+	my $pango = "<span";
+	while (my ($key, $value) = each %attributes) {
+		$pango .= " $key='$value'";
+	}
+	$pango .= sprintf ">%s</span>", escape_xml_text($text);
+
+	return Gtk2::Pango->parse_markup($pango);
+}
+
+
 # A true value
 1;
 
